
## Release Notes

**v1.6.0 - May 6, 2025**

* **FIXED** compatibility with Python=3.12

**v1.5.10 - October 12, 2023**

* **ENHANCEMENT** updating conesearch to work for bespoke HTM database IDs

**v1.5.8 - September 6, 2022**

* **FIXED** fixed issue with ISO C++17 not allow dynamic exception specifications. Install on Ubuntu 22.04 now works.

**v1.5.6 - May 10, 2022**

* **FIXED** doc fixes

**v1.5.5 - December 8, 2021**

* **FIXED** Install on macOS monterey

**v1.5.4 - August 16, 2021**

* **FIXED** Command-line tools

**v1.5.3 - June 23, 2020**

* **FIXED** When matching 2 lists of coordinates, if a list location was matched against more than one item in the second match list the angular separation of the first match got over-written by the second match.

**v1.5.1 - May 19, 2020**

* **FIXED** MacOS install was needlessly involved.

**v1.5.0 - May 8, 2020**


* Now compatible with python 3.\*
